"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._6594 import AbstractAssemblyCompoundCriticalSpeedAnalysis
    from ._6595 import AbstractShaftCompoundCriticalSpeedAnalysis
    from ._6596 import AbstractShaftOrHousingCompoundCriticalSpeedAnalysis
    from ._6597 import AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6598 import AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis
    from ._6599 import AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6600 import AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6601 import AssemblyCompoundCriticalSpeedAnalysis
    from ._6602 import BearingCompoundCriticalSpeedAnalysis
    from ._6603 import BeltConnectionCompoundCriticalSpeedAnalysis
    from ._6604 import BeltDriveCompoundCriticalSpeedAnalysis
    from ._6605 import BevelDifferentialGearCompoundCriticalSpeedAnalysis
    from ._6606 import BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis
    from ._6607 import BevelDifferentialGearSetCompoundCriticalSpeedAnalysis
    from ._6608 import BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis
    from ._6609 import BevelDifferentialSunGearCompoundCriticalSpeedAnalysis
    from ._6610 import BevelGearCompoundCriticalSpeedAnalysis
    from ._6611 import BevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6612 import BevelGearSetCompoundCriticalSpeedAnalysis
    from ._6613 import BoltCompoundCriticalSpeedAnalysis
    from ._6614 import BoltedJointCompoundCriticalSpeedAnalysis
    from ._6615 import ClutchCompoundCriticalSpeedAnalysis
    from ._6616 import ClutchConnectionCompoundCriticalSpeedAnalysis
    from ._6617 import ClutchHalfCompoundCriticalSpeedAnalysis
    from ._6618 import CoaxialConnectionCompoundCriticalSpeedAnalysis
    from ._6619 import ComponentCompoundCriticalSpeedAnalysis
    from ._6620 import ConceptCouplingCompoundCriticalSpeedAnalysis
    from ._6621 import ConceptCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6622 import ConceptCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6623 import ConceptGearCompoundCriticalSpeedAnalysis
    from ._6624 import ConceptGearMeshCompoundCriticalSpeedAnalysis
    from ._6625 import ConceptGearSetCompoundCriticalSpeedAnalysis
    from ._6626 import ConicalGearCompoundCriticalSpeedAnalysis
    from ._6627 import ConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6628 import ConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6629 import ConnectionCompoundCriticalSpeedAnalysis
    from ._6630 import ConnectorCompoundCriticalSpeedAnalysis
    from ._6631 import CouplingCompoundCriticalSpeedAnalysis
    from ._6632 import CouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6633 import CouplingHalfCompoundCriticalSpeedAnalysis
    from ._6634 import CVTBeltConnectionCompoundCriticalSpeedAnalysis
    from ._6635 import CVTCompoundCriticalSpeedAnalysis
    from ._6636 import CVTPulleyCompoundCriticalSpeedAnalysis
    from ._6637 import CycloidalAssemblyCompoundCriticalSpeedAnalysis
    from ._6638 import CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6639 import CycloidalDiscCompoundCriticalSpeedAnalysis
    from ._6640 import CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis
    from ._6641 import CylindricalGearCompoundCriticalSpeedAnalysis
    from ._6642 import CylindricalGearMeshCompoundCriticalSpeedAnalysis
    from ._6643 import CylindricalGearSetCompoundCriticalSpeedAnalysis
    from ._6644 import CylindricalPlanetGearCompoundCriticalSpeedAnalysis
    from ._6645 import DatumCompoundCriticalSpeedAnalysis
    from ._6646 import ExternalCADModelCompoundCriticalSpeedAnalysis
    from ._6647 import FaceGearCompoundCriticalSpeedAnalysis
    from ._6648 import FaceGearMeshCompoundCriticalSpeedAnalysis
    from ._6649 import FaceGearSetCompoundCriticalSpeedAnalysis
    from ._6650 import FEPartCompoundCriticalSpeedAnalysis
    from ._6651 import FlexiblePinAssemblyCompoundCriticalSpeedAnalysis
    from ._6652 import GearCompoundCriticalSpeedAnalysis
    from ._6653 import GearMeshCompoundCriticalSpeedAnalysis
    from ._6654 import GearSetCompoundCriticalSpeedAnalysis
    from ._6655 import GuideDxfModelCompoundCriticalSpeedAnalysis
    from ._6656 import HypoidGearCompoundCriticalSpeedAnalysis
    from ._6657 import HypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6658 import HypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6659 import InterMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6660 import KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis
    from ._6661 import KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis
    from ._6662 import KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis
    from ._6663 import KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis
    from ._6664 import KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis
    from ._6665 import KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis
    from ._6666 import KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6667 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6668 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6669 import MassDiscCompoundCriticalSpeedAnalysis
    from ._6670 import MeasurementComponentCompoundCriticalSpeedAnalysis
    from ._6671 import MountableComponentCompoundCriticalSpeedAnalysis
    from ._6672 import OilSealCompoundCriticalSpeedAnalysis
    from ._6673 import PartCompoundCriticalSpeedAnalysis
    from ._6674 import PartToPartShearCouplingCompoundCriticalSpeedAnalysis
    from ._6675 import PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis
    from ._6676 import PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis
    from ._6677 import PlanetaryConnectionCompoundCriticalSpeedAnalysis
    from ._6678 import PlanetaryGearSetCompoundCriticalSpeedAnalysis
    from ._6679 import PlanetCarrierCompoundCriticalSpeedAnalysis
    from ._6680 import PointLoadCompoundCriticalSpeedAnalysis
    from ._6681 import PowerLoadCompoundCriticalSpeedAnalysis
    from ._6682 import PulleyCompoundCriticalSpeedAnalysis
    from ._6683 import RingPinsCompoundCriticalSpeedAnalysis
    from ._6684 import RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis
    from ._6685 import RollingRingAssemblyCompoundCriticalSpeedAnalysis
    from ._6686 import RollingRingCompoundCriticalSpeedAnalysis
    from ._6687 import RollingRingConnectionCompoundCriticalSpeedAnalysis
    from ._6688 import RootAssemblyCompoundCriticalSpeedAnalysis
    from ._6689 import ShaftCompoundCriticalSpeedAnalysis
    from ._6690 import ShaftHubConnectionCompoundCriticalSpeedAnalysis
    from ._6691 import ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis
    from ._6692 import SpecialisedAssemblyCompoundCriticalSpeedAnalysis
    from ._6693 import SpiralBevelGearCompoundCriticalSpeedAnalysis
    from ._6694 import SpiralBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6695 import SpiralBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6696 import SpringDamperCompoundCriticalSpeedAnalysis
    from ._6697 import SpringDamperConnectionCompoundCriticalSpeedAnalysis
    from ._6698 import SpringDamperHalfCompoundCriticalSpeedAnalysis
    from ._6699 import StraightBevelDiffGearCompoundCriticalSpeedAnalysis
    from ._6700 import StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis
    from ._6701 import StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis
    from ._6702 import StraightBevelGearCompoundCriticalSpeedAnalysis
    from ._6703 import StraightBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6704 import StraightBevelGearSetCompoundCriticalSpeedAnalysis
    from ._6705 import StraightBevelPlanetGearCompoundCriticalSpeedAnalysis
    from ._6706 import StraightBevelSunGearCompoundCriticalSpeedAnalysis
    from ._6707 import SynchroniserCompoundCriticalSpeedAnalysis
    from ._6708 import SynchroniserHalfCompoundCriticalSpeedAnalysis
    from ._6709 import SynchroniserPartCompoundCriticalSpeedAnalysis
    from ._6710 import SynchroniserSleeveCompoundCriticalSpeedAnalysis
    from ._6711 import TorqueConverterCompoundCriticalSpeedAnalysis
    from ._6712 import TorqueConverterConnectionCompoundCriticalSpeedAnalysis
    from ._6713 import TorqueConverterPumpCompoundCriticalSpeedAnalysis
    from ._6714 import TorqueConverterTurbineCompoundCriticalSpeedAnalysis
    from ._6715 import UnbalancedMassCompoundCriticalSpeedAnalysis
    from ._6716 import VirtualComponentCompoundCriticalSpeedAnalysis
    from ._6717 import WormGearCompoundCriticalSpeedAnalysis
    from ._6718 import WormGearMeshCompoundCriticalSpeedAnalysis
    from ._6719 import WormGearSetCompoundCriticalSpeedAnalysis
    from ._6720 import ZerolBevelGearCompoundCriticalSpeedAnalysis
    from ._6721 import ZerolBevelGearMeshCompoundCriticalSpeedAnalysis
    from ._6722 import ZerolBevelGearSetCompoundCriticalSpeedAnalysis
