"""_1198.py

CylindricalGearLTCAContactChartDataAsTextFile
"""


from mastapy._internal import constructor
from mastapy.gears.cylindrical import _1200
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_LTCA_CONTACT_CHART_DATA_AS_TEXT_FILE = python_net_import('SMT.MastaAPI.Gears.Cylindrical', 'CylindricalGearLTCAContactChartDataAsTextFile')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalGearLTCAContactChartDataAsTextFile',)


class CylindricalGearLTCAContactChartDataAsTextFile(_1200.GearLTCAContactChartDataAsTextFile):
    """CylindricalGearLTCAContactChartDataAsTextFile

    This is a mastapy class.
    """

    TYPE = _CYLINDRICAL_GEAR_LTCA_CONTACT_CHART_DATA_AS_TEXT_FILE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalGearLTCAContactChartDataAsTextFile.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    def coefficient_of_friction_benedict_and_kelley(self):
        """ 'CoefficientOfFrictionBenedictAndKelley' is the original name of this method."""

        self.wrapped.CoefficientOfFrictionBenedictAndKelley()

    def gap_between_unloaded_flanks_transverse(self):
        """ 'GapBetweenUnloadedFlanksTransverse' is the original name of this method."""

        self.wrapped.GapBetweenUnloadedFlanksTransverse()

    def gear_a_depth_of_maximum_material_exposure_iso633642019(self):
        """ 'GearADepthOfMaximumMaterialExposureISO633642019' is the original name of this method."""

        self.wrapped.GearADepthOfMaximumMaterialExposureISO633642019()

    def gear_a_maximum_material_exposure_iso633642019(self):
        """ 'GearAMaximumMaterialExposureISO633642019' is the original name of this method."""

        self.wrapped.GearAMaximumMaterialExposureISO633642019()

    def gear_b_depth_of_maximum_material_exposure_iso633642019(self):
        """ 'GearBDepthOfMaximumMaterialExposureISO633642019' is the original name of this method."""

        self.wrapped.GearBDepthOfMaximumMaterialExposureISO633642019()

    def gear_b_maximum_material_exposure_iso633642019(self):
        """ 'GearBMaximumMaterialExposureISO633642019' is the original name of this method."""

        self.wrapped.GearBMaximumMaterialExposureISO633642019()

    def micropitting_contact_temperature_isotr1514412010(self):
        """ 'MicropittingContactTemperatureISOTR1514412010' is the original name of this method."""

        self.wrapped.MicropittingContactTemperatureISOTR1514412010()

    def micropitting_contact_temperature_isotr1514412014(self):
        """ 'MicropittingContactTemperatureISOTR1514412014' is the original name of this method."""

        self.wrapped.MicropittingContactTemperatureISOTR1514412014()

    def micropitting_contact_temperature_isots6336222018(self):
        """ 'MicropittingContactTemperatureISOTS6336222018' is the original name of this method."""

        self.wrapped.MicropittingContactTemperatureISOTS6336222018()

    def micropitting_flash_temperature_isotr1514412010(self):
        """ 'MicropittingFlashTemperatureISOTR1514412010' is the original name of this method."""

        self.wrapped.MicropittingFlashTemperatureISOTR1514412010()

    def micropitting_flash_temperature_isotr1514412014(self):
        """ 'MicropittingFlashTemperatureISOTR1514412014' is the original name of this method."""

        self.wrapped.MicropittingFlashTemperatureISOTR1514412014()

    def micropitting_flash_temperature_isots6336222018(self):
        """ 'MicropittingFlashTemperatureISOTS6336222018' is the original name of this method."""

        self.wrapped.MicropittingFlashTemperatureISOTS6336222018()

    def micropitting_safety_factor_isotr1514412010(self):
        """ 'MicropittingSafetyFactorISOTR1514412010' is the original name of this method."""

        self.wrapped.MicropittingSafetyFactorISOTR1514412010()

    def micropitting_safety_factor_isotr1514412014(self):
        """ 'MicropittingSafetyFactorISOTR1514412014' is the original name of this method."""

        self.wrapped.MicropittingSafetyFactorISOTR1514412014()

    def micropitting_safety_factor_isots6336222018(self):
        """ 'MicropittingSafetyFactorISOTS6336222018' is the original name of this method."""

        self.wrapped.MicropittingSafetyFactorISOTS6336222018()

    def minimum_lubricant_film_thickness_isotr1514412010(self):
        """ 'MinimumLubricantFilmThicknessISOTR1514412010' is the original name of this method."""

        self.wrapped.MinimumLubricantFilmThicknessISOTR1514412010()

    def minimum_lubricant_film_thickness_isotr1514412014(self):
        """ 'MinimumLubricantFilmThicknessISOTR1514412014' is the original name of this method."""

        self.wrapped.MinimumLubricantFilmThicknessISOTR1514412014()

    def minimum_lubricant_film_thickness_isots6336222018(self):
        """ 'MinimumLubricantFilmThicknessISOTS6336222018' is the original name of this method."""

        self.wrapped.MinimumLubricantFilmThicknessISOTS6336222018()

    def pressure_velocity_pv(self):
        """ 'PressureVelocityPV' is the original name of this method."""

        self.wrapped.PressureVelocityPV()

    def scuffing_contact_temperature_agma925a03(self):
        """ 'ScuffingContactTemperatureAGMA925A03' is the original name of this method."""

        self.wrapped.ScuffingContactTemperatureAGMA925A03()

    def scuffing_contact_temperature_agma925b22(self):
        """ 'ScuffingContactTemperatureAGMA925B22' is the original name of this method."""

        self.wrapped.ScuffingContactTemperatureAGMA925B22()

    def scuffing_contact_temperature_din399041987(self):
        """ 'ScuffingContactTemperatureDIN399041987' is the original name of this method."""

        self.wrapped.ScuffingContactTemperatureDIN399041987()

    def scuffing_contact_temperature_isotr1398912000(self):
        """ 'ScuffingContactTemperatureISOTR1398912000' is the original name of this method."""

        self.wrapped.ScuffingContactTemperatureISOTR1398912000()

    def scuffing_contact_temperature_isots6336202017(self):
        """ 'ScuffingContactTemperatureISOTS6336202017' is the original name of this method."""

        self.wrapped.ScuffingContactTemperatureISOTS6336202017()

    def scuffing_contact_temperature_isots6336202022(self):
        """ 'ScuffingContactTemperatureISOTS6336202022' is the original name of this method."""

        self.wrapped.ScuffingContactTemperatureISOTS6336202022()

    def scuffing_flash_temperature_agma925a03(self):
        """ 'ScuffingFlashTemperatureAGMA925A03' is the original name of this method."""

        self.wrapped.ScuffingFlashTemperatureAGMA925A03()

    def scuffing_flash_temperature_agma925b22(self):
        """ 'ScuffingFlashTemperatureAGMA925B22' is the original name of this method."""

        self.wrapped.ScuffingFlashTemperatureAGMA925B22()

    def scuffing_flash_temperature_din399041987(self):
        """ 'ScuffingFlashTemperatureDIN399041987' is the original name of this method."""

        self.wrapped.ScuffingFlashTemperatureDIN399041987()

    def scuffing_flash_temperature_isotr1398912000(self):
        """ 'ScuffingFlashTemperatureISOTR1398912000' is the original name of this method."""

        self.wrapped.ScuffingFlashTemperatureISOTR1398912000()

    def scuffing_flash_temperature_isots6336202017(self):
        """ 'ScuffingFlashTemperatureISOTS6336202017' is the original name of this method."""

        self.wrapped.ScuffingFlashTemperatureISOTS6336202017()

    def scuffing_flash_temperature_isots6336202022(self):
        """ 'ScuffingFlashTemperatureISOTS6336202022' is the original name of this method."""

        self.wrapped.ScuffingFlashTemperatureISOTS6336202022()

    def scuffing_safety_factor_agma925a03(self):
        """ 'ScuffingSafetyFactorAGMA925A03' is the original name of this method."""

        self.wrapped.ScuffingSafetyFactorAGMA925A03()

    def scuffing_safety_factor_agma925b22(self):
        """ 'ScuffingSafetyFactorAGMA925B22' is the original name of this method."""

        self.wrapped.ScuffingSafetyFactorAGMA925B22()

    def scuffing_safety_factor_din399041987(self):
        """ 'ScuffingSafetyFactorDIN399041987' is the original name of this method."""

        self.wrapped.ScuffingSafetyFactorDIN399041987()

    def scuffing_safety_factor_isotr1398912000(self):
        """ 'ScuffingSafetyFactorISOTR1398912000' is the original name of this method."""

        self.wrapped.ScuffingSafetyFactorISOTR1398912000()

    def scuffing_safety_factor_isots6336202017(self):
        """ 'ScuffingSafetyFactorISOTS6336202017' is the original name of this method."""

        self.wrapped.ScuffingSafetyFactorISOTS6336202017()

    def scuffing_safety_factor_isots6336202022(self):
        """ 'ScuffingSafetyFactorISOTS6336202022' is the original name of this method."""

        self.wrapped.ScuffingSafetyFactorISOTS6336202022()

    def sliding_power_loss(self):
        """ 'SlidingPowerLoss' is the original name of this method."""

        self.wrapped.SlidingPowerLoss()

    def sliding_velocity(self):
        """ 'SlidingVelocity' is the original name of this method."""

        self.wrapped.SlidingVelocity()

    def specific_lubricant_film_thickness_isotr1514412010(self):
        """ 'SpecificLubricantFilmThicknessISOTR1514412010' is the original name of this method."""

        self.wrapped.SpecificLubricantFilmThicknessISOTR1514412010()

    def specific_lubricant_film_thickness_isotr1514412014(self):
        """ 'SpecificLubricantFilmThicknessISOTR1514412014' is the original name of this method."""

        self.wrapped.SpecificLubricantFilmThicknessISOTR1514412014()

    def specific_lubricant_film_thickness_isots6336222018(self):
        """ 'SpecificLubricantFilmThicknessISOTS6336222018' is the original name of this method."""

        self.wrapped.SpecificLubricantFilmThicknessISOTS6336222018()
