"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2520 import BeltDrive
    from ._2521 import BeltDriveType
    from ._2522 import Clutch
    from ._2523 import ClutchHalf
    from ._2524 import ClutchType
    from ._2525 import ConceptCoupling
    from ._2526 import ConceptCouplingHalf
    from ._2527 import Coupling
    from ._2528 import CouplingHalf
    from ._2529 import CrowningSpecification
    from ._2530 import CVT
    from ._2531 import CVTPulley
    from ._2532 import PartToPartShearCoupling
    from ._2533 import PartToPartShearCouplingHalf
    from ._2534 import Pulley
    from ._2535 import RigidConnectorStiffnessType
    from ._2536 import RigidConnectorTiltStiffnessTypes
    from ._2537 import RigidConnectorToothLocation
    from ._2538 import RigidConnectorToothSpacingType
    from ._2539 import RigidConnectorTypes
    from ._2540 import RollingRing
    from ._2541 import RollingRingAssembly
    from ._2542 import ShaftHubConnection
    from ._2543 import SplineLeadRelief
    from ._2544 import SpringDamper
    from ._2545 import SpringDamperHalf
    from ._2546 import Synchroniser
    from ._2547 import SynchroniserCone
    from ._2548 import SynchroniserHalf
    from ._2549 import SynchroniserPart
    from ._2550 import SynchroniserSleeve
    from ._2551 import TorqueConverter
    from ._2552 import TorqueConverterPump
    from ._2553 import TorqueConverterSpeedRatio
    from ._2554 import TorqueConverterTurbine
