"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2499 import BoostPressureInputOptions
    from ._2500 import InputPowerInputOptions
    from ._2501 import PressureRatioInputOptions
    from ._2502 import RotorSetDataInputFileOptions
    from ._2503 import RotorSetMeasuredPoint
    from ._2504 import RotorSpeedInputOptions
    from ._2505 import SuperchargerMap
    from ._2506 import SuperchargerMaps
    from ._2507 import SuperchargerRotorSet
    from ._2508 import SuperchargerRotorSetDatabase
    from ._2509 import YVariableForImportedData
